# coding: utf-8

"""
    Data Repository API

    <details><summary>This document defines the REST API for the Terra Data Repository.</summary> <p> **Status: design in progress** There are a few top-level endpoints (besides some used by swagger):  * / - generated by swagger: swagger API page that provides this documentation and a live UI for submitting REST requests  * /status - provides the operational status of the service  * /configuration - provides the basic configuration and information about the service  * /api - is the authenticated and authorized Data Repository API  * /ga4gh/drs/v1 - is a transcription of the Data Repository Service API  The API endpoints are organized by interface. Each interface is separately versioned. <p> **Notes on Naming** <p> All of the reference items are suffixed with \\\"Model\\\". Those names are used as the class names in the generated Java code. It is helpful to distinguish these model classes from other related classes, like the DAO classes and the operation classes. </details>   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from data_repo_client.configuration import Configuration


class DRSPassportRequestModel(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'expand': 'bool',
        'passports': 'list[str]'
    }

    attribute_map = {
        'expand': 'expand',
        'passports': 'passports'
    }

    def __init__(self, expand=False, passports=None, local_vars_configuration=None):  # noqa: E501
        """DRSPassportRequestModel - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._expand = None
        self._passports = None
        self.discriminator = None

        if expand is not None:
            self.expand = expand
        self.passports = passports

    @property
    def expand(self):
        """Gets the expand of this DRSPassportRequestModel.  # noqa: E501

        If false and the object_id refers to a bundle, then the ContentsObject array contains only those objects directly contained in the bundle. That is, if the bundle contains other bundles, those other bundles are not recursively included in the result. If true and the object_id refers to a bundle, then the entire set of objects in the bundle is expanded. That is, if the bundle contains aother bundles, then those other bundles are recursively expanded and included in the result. Recursion continues through the entire sub-tree of the bundle. If the object_id refers to a blob, then the query parameter is ignored.  # noqa: E501

        :return: The expand of this DRSPassportRequestModel.  # noqa: E501
        :rtype: bool
        """
        return self._expand

    @expand.setter
    def expand(self, expand):
        """Sets the expand of this DRSPassportRequestModel.

        If false and the object_id refers to a bundle, then the ContentsObject array contains only those objects directly contained in the bundle. That is, if the bundle contains other bundles, those other bundles are not recursively included in the result. If true and the object_id refers to a bundle, then the entire set of objects in the bundle is expanded. That is, if the bundle contains aother bundles, then those other bundles are recursively expanded and included in the result. Recursion continues through the entire sub-tree of the bundle. If the object_id refers to a blob, then the query parameter is ignored.  # noqa: E501

        :param expand: The expand of this DRSPassportRequestModel.  # noqa: E501
        :type: bool
        """

        self._expand = expand

    @property
    def passports(self):
        """Gets the passports of this DRSPassportRequestModel.  # noqa: E501

        the encoded JWT GA4GH Passport that contains embedded Visas.  The overall JWT is signed as are the individual Passport Visas.  # noqa: E501

        :return: The passports of this DRSPassportRequestModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._passports

    @passports.setter
    def passports(self, passports):
        """Sets the passports of this DRSPassportRequestModel.

        the encoded JWT GA4GH Passport that contains embedded Visas.  The overall JWT is signed as are the individual Passport Visas.  # noqa: E501

        :param passports: The passports of this DRSPassportRequestModel.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and passports is None:  # noqa: E501
            raise ValueError("Invalid value for `passports`, must not be `None`")  # noqa: E501

        self._passports = passports

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DRSPassportRequestModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DRSPassportRequestModel):
            return True

        return self.to_dict() != other.to_dict()
